Custom Doxygen Theme
====================

This is a custom [doxygen](http://www.stack.nl/~dimitri/doxygen/) theme
inspired by [Mac Developer Library](https://developer.apple.com/library/mac/navigation/index.html).

Metro Theme
-----------

Metro UI theme in the `metro` directory has been pulled from
[nafSadh's](https://github.com/nafSadh)
[fork](https://github.com/nafSadh/doxygen-theme-metro) of the original theme.

Example
-------

An example of documentation using this theme can be found at http://milik.cz/~jan/cppapp/docs/index.html.

Installation
------------

To install this theme, copy `customdoxygen.css` and `DoxygenLayout.xml`
somewhere to your project and in your `Doxyfile`, change the following
settings:

 * `HTML_EXTRA_STYLESHEET` - set to point to `customdoxygen.css`
 * `LAYOUT_FILE` - set to point to `DoxygenLayout.xml`

License
-------

This theme is distribute under GNU General Public License v3. See the `LICENSE`
file for the full text of the license.

Alternatively, see the [GNU website](http://www.gnu.org/licenses/) for more
infomation about GPL.

